/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

import com.lodgon.dali.core.entity.Content;
import com.lodgon.dali.core.entity.Group;
import com.lodgon.dali.core.entity.User;
import java.util.HashSet;
import java.util.Set;

/**
 * Bundles all the parameters that can be used to search the DaliCore content store.
 *
 * @author erwin
 */
public class ContentSearchParams extends ParentSearchParams<Content> {
	private User author;
	private Integer authorId;
  private Set<String> contents = new HashSet<String>();
	private Group group;
	private Integer groupId;
  private Set<String> summaries = new HashSet<String>();
  private Set<String> tags = new HashSet<String>();
	private Set<String> titles = new HashSet<String>();

	/**
	 * The managed User entity that is the author of the content to search for.
	 *
	 * @return the managed User entity as the author of a content
	 */
	public User getAuthor() {
		return author;
	}

	/**
	 * Defines the managed User entity that is the author of the content to search
	 * for.
	 *
	 * @param author the managed User entity as the author of a content
	 */
	public void setAuthor(User author) {
		this.author = author;
	}

	/**
	 * The id of a User entity that is the author of the content to search for.
	 *
	 * @return the id of a User entity as the author of a content
	 */
	public Integer getAuthorId() {
		return authorId;
	}

	/**
	 * Defines the id of a User entity that is the author of the content to search
	 * for.
	 *
	 * @param authorId the id of a User entity as the author of a content
	 */
	public void setAuthorId(Integer authorId) {
		this.authorId = authorId;
	}

	/**
	 * The list of contents to search by.
	 *
	 * @return the list of contents to search by
	 */
	public Set<String> getContents() {
		return contents;
	}

	/**
	 * Defines the list of contents to search by. You can use * as a wildcard.
	 *
	 * @param contents a list of contents to search by
	 */
	public void setContents(Set<String> contents) {
		this.contents = contents;
	}

	/**
	 * The managed Group entity where a content should belong to.
	 *
	 * @return the managed Group entity a content should belong to
	 */
	public Group getGroup() {
		return group;
	}

	/**
	 * Defines the managed Group entity where a content should belong to.
	 *
	 * @param group the managed Group entity a content should belong to
	 */
	public void setGroup(Group group) {
		this.group = group;
	}

	/**
	 * The id of a Group entity where a content should belong to.
	 *
	 * @return the id of a Group entity a content should belong to
	 */
	public Integer getGroupId() {
		return groupId;
	}

	/**
	 * Defines the id of a Group entity where a content should belong to.
	 *
	 * @param groupId the id of a Group entity a content should belong to
	 */
	public void setGroupId(Integer groupId) {
		this.groupId = groupId;
	}

	/**
	 * The list of summaries to search by.
	 *
	 * @return the list of summaries to search by
	 */
	public Set<String> getSummaries() {
		return summaries;
	}

	/**
	 * Defines the list of summaries to search by. You can use * as a wildcard.
	 *
	 * @param summaries a list of summaries to search by
	 */
	public void setSummaries(Set<String> summaries) {
		this.summaries = summaries;
	}

	/**
	 * The list of tags to search by.
	 *
	 * @return the list of tags to search by
	 */
	public Set<String> getTags() {
		return tags;
	}

	/**
	 * Defines the list of tags to search by. You can not use * as a wildcard,
	 * these will be processed as is.
	 *
	 * @param tags a list of tags to search by
	 */
	public void setTags(Set<String> tags) {
		this.tags = tags;
	}

	/**
	 * The list of titles to search by.
	 *
	 * @return the list of titles to search by
	 */
	public Set<String> getTitles() {
		return titles;
	}

	/**
	 * Defines the list of titles to search by. You can use * as a wildcard.
	 *
	 * @param titles a list of titles to search by
	 */
	public void setTitles(Set<String> titles) {
		this.titles = titles;
	}
}
