/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

import com.lodgon.dali.core.entity.Group;
import com.lodgon.dali.core.entity.User;
import java.util.HashSet;
import java.util.Set;

/**
 * Bundles all the parameters that can be used to search the DaliCore group store.
 *
 * @author joeri
 */
public class GroupSearchParams extends ParentSearchParams<Group> {
	private User author;
	private Integer authorId;
	private User member;
	private Integer memberId;
	private Set<String> names = new HashSet<String>();

	/**
	 * The managed User entity that is the author of the group to search for.
	 *
	 * @return the managed User entity as the author of a group
	 */
	public User getAuthor() {
		return author;
	}

	/**
	 * Defines the managed User entity that is the author of the group to search
	 * for.
	 *
	 * @param author the managed User entity as the author of a group
	 */
	public void setAuthor(User author) {
		this.author = author;
	}

	/**
	 * The id of a User entity that is the author of the group to search for.
	 *
	 * @return the id of a User entity as the author of a group
	 */
	public Integer getAuthorId() {
		return authorId;
	}

	/**
	 * Defines the id of a User entity that is the author of the group to search
	 * for.
	 *
	 * @param authorId the id of a User entity as the author of a group
	 */
	public void setAuthorId(Integer authorId) {
		this.authorId = authorId;
	}

	/**
	 * The managed User entity that is a member of the group to search for.
	 *
	 * @return the managed User entity as a member of a group
	 */
	public User getMember() {
		return member;
	}

	/**
	 * Defines the managed User entity that is a member of the group to search
	 * for.
	 *
	 * @param member the managed User entity as a member of a group
	 */
	public void setMember(User member) {
		this.member = member;
	}

	/**
	 * The id of a User entity that is a member of the group to search for.
	 *
	 * @return the id of a User entity as a member of a group
	 */
	public Integer getMemberId() {
		return memberId;
	}

	/**
	 * Defines the id of a User entity that is a member of the group to search
	 * for.
	 *
	 * @param memberId the id of a User entity as a member of a group
	 */
	public void setMemberId(Integer memberId) {
		this.memberId = memberId;
	}

	/**
	 * The list of names to search by.
	 *
	 * @return the list of names to search by
	 */
	public Set<String> getNames() {
		return names;
	}

	/**
	 * Defines the list of names to search by. You can use * as a wildcard.
	 *
	 * @param names a list of names to search by
	 */
	public void setNames(Set<String> names) {
		this.names = names;
	}
}
