/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.entity.search;

/**
 * Base class that defines search parameters specific to searching within a
 * parent and child tree.
 *
 * @author joeri
 */
public class ParentSearchParams<T> extends SearchParams {
  private Integer depth;
	private T parent;
	private Integer parentId;

	/**
	 * How deep to search within the underlying child structure.
	 *
	 * @return the maximum depth to search within the child structure
	 */
	public Integer getDepth() {
		return depth;
	}

	/**
	 * Defines how deep to search within the underlying child structure. A depth
	 * value of 1 will search within the children directly beneath the specified
	 * parent. A depth of 2 will search even within their children and so on. A
	 * depth value of <code>null</null> is the same as specifying a depth of 1.
	 *
	 * @param depth the maximum depth to search within the child structure
	 */
	public void setDepth(Integer depth) {
		this.depth = depth;
	}

	/**
	 * The managed entity that defines the starting point in the tree structure.
	 *
	 * @return the managed entity from where to start the search in a tree
	 */
	public T getParent() {
		return parent;
	}

	/**
	 * Defines the managed entity from where in the tree structure the search
	 * should be started.
	 *
	 * @param parent the managed entity to start the search from in a tree structure
	 */
	public void setParent(T parent) {
		this.parent = parent;
	}

	/**
	 * The id of the entity that defines the starting point in the tree structure.
	 *
	 * @return the id of an entity from where to start the search in a tree
	 */
	public Integer getParentId() {
		return parentId;
	}

	/**
	 * Defines the id of the entity from where in the tree structure the search
	 * should be started.
	 *
	 * @param parentId the id of an entity to start the search from in a tree structure
	 */
	public void setParentId(Integer parentId) {
		this.parentId = parentId;
	}
}
