/*
 * Copyright (c) 2009-2011 LodgON  (http://www.lodgon.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.lodgon.dali.core.search;

import com.lodgon.dali.core.entity.search.SearchParams;
import java.util.List;

/**
 * An implementation of SearchProvider is able to count or search for entities,
 * taking into account the specified search parameters.
 *
 * @author Joeri
 */
public interface SearchProvider<E> {

	/**
   * Count the number of entities that match the specified search parameters
	 * within an application.
	 *
   * @param appKey the key of the application to search in
	 * @param searchParams the search parameters that are used to generate the search query
   * @return the total number of entities that match the search in the application
   */
	public Long count(String appKey, SearchParams searchParams);

	/**
	 * Finds all entities that match the specified search parameters within an
	 * application.
	 *
   * @param appKey the key of the application to search in
	 * @param searchParams the search parameters that are used to generate the search query
	 * @return all entities that match the specified search parameters in the application
	 */
	public List<E> search(String appKey, SearchParams searchParams);

}
